@@ -8,13 +8,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "libmisc/misc.h"
-#include "libruntime/runtime.h"
-#include "libparser/parser.h"
-#include "libeval/eval.h"
-#include "libstdlib/stdlib.h"
+#include "api.h"
 
-#define VERSION 	"0.9.2"
+#define VERSION 	"0.9.3"
 
 #define MODE_NORMAL	0x0
 #define MODE_CHECK	0x1
@@ -32,9 +28,10 @@ static char *filename = NULL;
 static int filearg = 0;
 
 /*
- * Current script data
+ * Execution context and script data
  */
-static stmt_list *script = NULL;
+arena_ctx context = NULL;
+arena_script script = NULL;
 
 /*
  * Print usage message
@@ -83,7 +80,8 @@ static void options(int argc, char **argv)
         in_opts = 0;
         continue;
       } else if (*opt == '-') {
-        fatal("unknown option `%s'", opt);
+        fprintf(stderr, "arena: unknown option `%s'\n", opt);
+        exit(1);
       }
     }
     if (!filename) {
@@ -95,14 +93,12 @@ static void options(int argc, char **argv)
 }
 
 /*
- * Free script data
+ * Memory cleanup at interpreter exit
  */
-static void script_teardown(void)
+static void teardown(void)
 {
-  if (script) {
-    stmt_list_free(script);
-    script = NULL;
-  }
+  if (context) arena_free_ctx(context);
+  if (script) arena_free_script(script);
 }
 
 /*
@@ -118,34 +114,22 @@ int main(int argc, char **argv)
   setvbuf(stdout, NULL, _IONBF, 0);
   setvbuf(stderr, NULL, _IONBF, 0);
 
-  /* disable source line printing for option errors */
-  source_line = 0;
-
   options(argc, argv);
+  atexit(teardown);
   
   if (!filename) {
-    fatal("missing script name on command line");
+    fprintf(stderr, "arena: missing script name on command line\n");
+    exit(1);
   }
 
-  /* enable source line printing for syntax errors */
-  source_line = 1;
-
-  /* initialize state */
-  atexit(script_teardown);
-  symtab_stack_init();
-  stdlib_register(argc - filearg, argv + filearg);
-
-  /* parse file */  
-  script = parse_file(filename);
-  source_line = 1;
-  source_col  = 0;
+  context = arena_new_ctx(argc - filearg, argv + filearg);
+  script  = arena_new_script(filename);
 
   /* execute operation */
   if (mode == MODE_NORMAL) {  
-    call_exception_pointer(&except_flag);
-    eval_stmt_list(script, 0);
+    arena_execute_script(context, script);
   } else if (mode == MODE_DUMP) {
-    stmt_list_dump(script, 0);
+    arena_dump_script(script);
   }
 
   return 0;
