@@ -37,13 +37,13 @@ static value_type typeval(const char *typespec)
 /*
  * Evaluate cast
  */
-value *eval_cast(expr *ex)
+value *eval_cast(arena_state *s, expr *ex)
 {
   value *val;
   
   sanity(ex);
   
-  val = eval_expr(ex->inner);
-  value_cast_inplace(&val, typeval(ex->name));
+  val = eval_expr(s, ex->inner);
+  value_cast_inplace(s, &val, typeval(ex->name));
   return val;
 }
