@@ -11,21 +11,21 @@
 /*
  * Evaluate post-increment operator
  */
-static value *postincrement(expr *ex)
+static value *postincrement(arena_state *s, expr *ex)
 {
   value *val, *copy;
   
-  val = eval_expr(ex);
-  value_cast_inplace(&val, VALUE_TYPE_INT);
+  val = eval_expr(s, ex);
+  value_cast_inplace(s, &val, VALUE_TYPE_INT);
 
   copy = value_make_int(val->value_u.int_val);
   
   ++val->value_u.int_val;
   
   if (ex->type == EXPR_REF) {
-    symtab_stack_add_variable(ex->name, val);
+    symtab_stack_add_variable(s, ex->name, val);
   } else if (ex->type == EXPR_REF_ARRAY) {
-    eval_assign_array_direct(ex->name, ex->argc, ex->argv, val);
+    eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
   }
   value_free(val);
 
@@ -35,21 +35,21 @@ static value *postincrement(expr *ex)
 /*
  * Evaluate post-decrement operator
  */
-static value *postdecrement(expr *ex)
+static value *postdecrement(arena_state *s, expr *ex)
 {
   value *val, *copy;
   
-  val = eval_expr(ex);
-  value_cast_inplace(&val, VALUE_TYPE_INT);
+  val = eval_expr(s, ex);
+  value_cast_inplace(s, &val, VALUE_TYPE_INT);
 
   copy = value_make_int(val->value_u.int_val);
   
   --val->value_u.int_val;
   
   if (ex->type == EXPR_REF) {
-    symtab_stack_add_variable(ex->name, val);
+    symtab_stack_add_variable(s, ex->name, val);
   } else if (ex->type == EXPR_REF_ARRAY) {
-    eval_assign_array_direct(ex->name, ex->argc, ex->argv, val);
+    eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
   }
   value_free(val);
 
@@ -59,7 +59,7 @@ static value *postdecrement(expr *ex)
 /*
  * Evaluate postfix operator
  */
-value *eval_postfix(expr *ex)
+value *eval_postfix(arena_state *s, expr *ex)
 {
   value *res = NULL;
   
@@ -67,10 +67,10 @@ value *eval_postfix(expr *ex)
 
   switch (ex->op) {
     case OPTYPE_POSTINC:
-      res = postincrement(ex->inner);
+      res = postincrement(s, ex->inner);
       break;
     case OPTYPE_POSTDEC:
-      res = postdecrement(ex->inner);
+      res = postdecrement(s, ex->inner);
       break;
     default:
       sanity(0);
