@@ -14,6 +14,11 @@ extern FILE *yyin;
 
 void yyparse(void);
 
+/*
+ * Current interpreter state
+ */
+arena_state *parser_state = NULL;
+
 /*
  * Tear down internal parser memory
  */
@@ -32,18 +37,19 @@ static void parse_teardown(void)
  * This function tries to parse the given file and returns the
  * resulting statement list.
  */
-stmt_list *parse_file(char *path)
+stmt_list *parse_file(arena_state *s, char *path)
 {
   FILE *file;
   
   sanity(path);
   
-  source_file = path;
+  parser_state = s;
+  s->source_file = path;
 
   file = fopen(path, "r");
   if (!file) {
-    source_line = 0;
-    fatal("could not open input file");
+    s->source_line = 0;
+    fatal(s, "could not open input file");
   }
 
   atexit(parse_teardown);
