@@ -62,6 +62,15 @@ void value_free(value *val)
     case VALUE_TYPE_FN:
       call_sig_free(val->value_u.fn_val);
       break;
+    case VALUE_TYPE_RES:
+      --val->value_u.res_val->refcount;
+      if (val->value_u.res_val->refcount == 0) {
+        if (val->value_u.res_val->release) {
+          val->value_u.res_val->release(val->value_u.res_val->data);
+        }
+        free(val->value_u.res_val);
+      }
+      break;
   }
   
   free(val);
