@@ -14,7 +14,7 @@
  * Terminates the program and returns its int argument as
  * the program's exit status.
  */
-value *sys_exit(unsigned int argc, value **argv)
+value *sys_exit(arena_state *s, unsigned int argc, value **argv)
 {
   int status = argv[0]->value_u.int_val;
 
@@ -29,7 +29,7 @@ value *sys_exit(unsigned int argc, value **argv)
  * Tries to get the value of the given environment variable. Returns
  * the value as a string on success, or void on failure.
  */
-value *sys_getenv(unsigned int argc, value **argv)
+value *sys_getenv(arena_state *s, unsigned int argc, value **argv)
 {
   const char *name = argv[0]->value_u.string_val.value;
   char *env;
@@ -47,7 +47,7 @@ value *sys_getenv(unsigned int argc, value **argv)
  * command interpreter. Returns the exit code of the command on
  * success, or void on failure.
  */
-value *sys_system(unsigned int argc, value **argv)
+value *sys_system(arena_state *s, unsigned int argc, value **argv)
 {
   const char *cmd = argv[0]->value_u.string_val.value;
   int res;
